@@ -31,6 +31,14 @@ typedef unsigned long __kernel_size_t;
 typedef unsigned int __kernel_size_t;
 #endif
 
+#define __force
+typedef uint16_t __le16;
+typedef uint16_t __be16;
+typedef uint32_t __le32;
+typedef uint32_t __be32;
+typedef uint64_t __le64;
+typedef uint64_t __be64;
+
 __END_DECLS
 
 #endif
