@@ -11,8 +11,16 @@ struct FTW {
   int level;
 };
 
-int ftw (const char *dir, int (*fn)(const char *file, const struct stat *sb, int flag), int depth) __THROW;
-int  nftw (const char *dir, int (*fn)(const char *file, const struct stat *sb, int flag, struct FTW *s), int depth, int flags) __THROW;
+int ftw(const char *dir, int (*fn)(const char *file, const struct stat *sb, int flag), int depth) __THROW;
+int nftw(const char *dir, int (*fn)(const char *file, const struct stat *sb, int flag, struct FTW *s), int depth, int flags) __THROW;
+
+#ifndef __NO_STAT64
+int ftw64(const char *dir, int (*fn)(const char *file, const struct stat64 *sb, int flag), int depth) __THROW;
+
+#if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
+#define ftw(dir,fn,depth) ftw64(dir,fn,depth)
+#endif
+#endif
 
 enum
 {
