@@ -4,6 +4,8 @@
 #include <sys/cdefs.h>
 #include <sys/types.h>
 
+__BEGIN_DECLS
+
 typedef struct {
 	size_t gl_pathc;    /* Count of paths matched so far  */
 	char **gl_pathv;    /* List of matched pathnames.  */
@@ -53,5 +55,6 @@ void globfree(glob_t *pglob) __THROW;
    GLOB_ABORTED.  Provide a compatibility definition here.  */
 #define GLOB_ABEND GLOB_ABORTED
 
+__END_DECLS
 
 #endif
