@@ -2,9 +2,10 @@
 #define _SCHED_H 1
 
 #include <time.h>
-
 #include <sys/types.h>
 
+__BEGIN_DECLS
+
 /*
  * cloning flags:
  */
@@ -42,17 +43,17 @@ struct sched_param {
 
 /* END OF COPY form kernel-header */
 
-int __sched_setparam(pid_t pid, const struct sched_param *p);
-int sched_setparam(pid_t pid, const struct sched_param *p);
+int __sched_setparam(pid_t pid, const struct sched_param* p);
+int sched_setparam(pid_t pid, const struct sched_param* p);
 
-int __sched_getparam(pid_t pid, struct sched_param *p);
-int sched_getparam(pid_t pid, struct sched_param *p);
+int __sched_getparam(pid_t pid, struct sched_param* p);
+int sched_getparam(pid_t pid, struct sched_param* p);
 
 int __sched_getscheduler(pid_t pid);
 int sched_getscheduler(pid_t pid);
 
-int __sched_setscheduler(pid_t pid, int policy, const struct sched_param *p);
-int sched_setscheduler(pid_t pid, int policy, const struct sched_param *p);
+int __sched_setscheduler(pid_t pid, int policy, const struct sched_param* p);
+int sched_setscheduler(pid_t pid, int policy, const struct sched_param* p);
 
 int __sched_yield(void);
 int sched_yield(void);
@@ -63,7 +64,9 @@ int sched_get_priority_max(int policy);
 int __sched_get_priority_min(int policy);
 int sched_get_priority_min(int policy);
 
-int __sched_rr_get_interval(pid_t pid, struct timespec *tp);
-int sched_rr_get_interval(pid_t pid, struct timespec *tp);
+int __sched_rr_get_interval(pid_t pid, struct timespec* tp);
+int sched_rr_get_interval(pid_t pid, struct timespec* tp);
+
+__END_DECLS
 
 #endif
