@@ -53,7 +53,7 @@
 #endif
 
 #ifndef __i386__
-#define regparm(x)
+#define __regparm__(x)
 #endif
 
 #if (__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 2))
@@ -63,10 +63,23 @@
 #define __deprecated__
 #endif
 
-#if (__GNUC_ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 3))
+#if (__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 3))
 # define __nonnull(params) __attribute__ ((__nonnull__ params))
 #else
 # define __nonnull(params)
 #endif
 
+#if (__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 4))
+# define __attribute_used __attribute__ ((__used__))
+#else
+# define __attribute_used
+#endif
+
+#if (__GNUC__ >= 4)
+#define __needsNULL__(x) __sentinel__(x)
+#else
+#define __needsNULL__(x)
+#define __sentinel__
+#endif
+
 #endif
