@@ -1,6 +1,10 @@
 #ifndef _SYS_REBOOT_H
 #define _SYS_REBOOT_H
 
+#include <sys/cdefs.h>
+
+__BEGIN_DECLS
+
 #define	LINUX_REBOOT_MAGIC1	0xfee1dead
 #define	LINUX_REBOOT_MAGIC2	672274793
 #define	LINUX_REBOOT_MAGIC2A	85072278
@@ -23,4 +27,6 @@ int reboot (int flag);
 #define RB_DISABLE_CAD	0
 #define RB_POWER_OFF	0x4321fedc
 
+__END_DECLS
+
 #endif	/* _SYS_REBOOT_H */
