@@ -44,11 +44,11 @@ typedef unsigned long int clock_t;	/* Used for system times in
 */
 
 #if defined(__alpha__) || defined(__ia64__) || defined(__sparc64__) || defined(__s390x__)
-    typedef unsigned int dev_t;		/* Used for device IDs. */
-    typedef unsigned int gid_t;		/* Used for group IDs. */
-    typedef unsigned int mode_t;	/* Used for some file attributes. */
-    typedef unsigned int nlink_t;	/* Used for link counts. */
-    typedef unsigned int uid_t;		/* Used for user IDs. */
+    typedef uint32_t dev_t;		/* Used for device IDs. */
+    typedef uint32_t gid_t;		/* Used for group IDs. */
+    typedef uint32_t mode_t;		/* Used for some file attributes. */
+    typedef uint32_t nlink_t;		/* Used for link counts. */
+    typedef uint32_t uid_t;		/* Used for user IDs. */
 #elif defined(__arm__) || defined(__i386__) || defined(__sparc__) || defined(__s390__) /* make sure __s390x__ hits before __s390__ */
     typedef unsigned short dev_t;
     typedef unsigned short gid_t;
@@ -67,7 +67,7 @@ typedef unsigned long int clock_t;	/* Used for system times in
     typedef unsigned int mode_t;
     typedef int nlink_t;
     typedef int uid_t;
-#elif defined(powerpc)
+#elif defined(__powerpc__) && !defined(__powerpc64__)
     typedef unsigned int dev_t;
     typedef unsigned int gid_t;
     typedef unsigned int mode_t;
@@ -75,18 +75,18 @@ typedef unsigned long int clock_t;	/* Used for system times in
     typedef unsigned int uid_t;
 #elif defined(__powerpc64__) || defined(__x86_64__)
     typedef unsigned long dev_t;
-    typedef unsigned int gid_t;
-    typedef unsigned int mode_t;
+    typedef uint32_t gid_t;
+    typedef uint32_t mode_t;
     typedef unsigned long nlink_t;
-    typedef unsigned int uid_t;
+    typedef uint32_t uid_t;
 #endif
 
-typedef signed int id_t;		/* Used as a general identifier; can be
+typedef int32_t id_t;			/* Used as a general identifier; can be
 					   used to contain at least a pid_t,
 					   uid_t or a gid_t. */
 typedef unsigned long ino_t;		/* Used for file serial numbers. */
-typedef signed int key_t;		/* Used for interprocess communication. */
-typedef signed int pid_t;		/* Used for process IDs and process group IDs. */
+typedef int32_t key_t;			/* Used for interprocess communication. */
+typedef int32_t pid_t;			/* Used for process IDs and process group IDs. */
 typedef signed long ssize_t;		/* Used for a count of bytes or an error indication. */
 typedef signed long suseconds_t;	/* Used for time in microseconds. */
 typedef signed long time_t;		/* Used for time in seconds. */
@@ -108,14 +108,14 @@ __extension__ typedef signed long long blkcnt64_t;
 typedef uint32_t uid32_t;
 typedef uint32_t gid32_t;
 
-typedef int clockid_t;
-typedef int timer_t;
+typedef int32_t clockid_t;
+typedef int32_t timer_t;
 
 typedef long int fpos_t;
 
 #define __socklen_t_defined
-typedef unsigned int socklen_t;
-typedef unsigned short sa_family_t;
+typedef uint32_t socklen_t;
+typedef uint16_t sa_family_t;
 
 
 #ifdef _BSD_SOURCE
