@@ -118,7 +118,7 @@ int sync(void) __THROW;
 
 int isatty(int desc) __THROW;
 
-void _exit(int status) __THROW __attribute__((noreturn));
+void _exit(int status) __THROW __attribute__((__noreturn__));
 
 int daemon(int nochdir,int noclose) __THROW;
 
@@ -142,7 +142,6 @@ int setreuid(uid_t ruid, uid_t euid) __THROW;
 #define seteuid(euid) setreuid(-1,euid)
 #define setegid(egid) setregid(-1,egid)
 
-int rename(const char *oldpath, const char *newpath) __THROW;
 int truncate(const char *path, off_t length) __THROW;
 int ftruncate(int fd, off_t length) __THROW;
 #ifndef __NO_STAT64
@@ -243,6 +242,7 @@ int vhangup(void) __THROW;
 
 extern char **__environ;
 
+#ifndef __NO_STAT64
 #if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
 #define open open64
 #define creat creat64
@@ -250,6 +250,7 @@ extern char **__environ;
 #define ftruncate ftruncate64
 #define getdents getdents64
 #endif
+#endif
 
 #ifdef _LINUX_SOURCE
 int pivot_root(const char *new_root, const char *put_old) __THROW;
