@@ -47,8 +47,10 @@ int __dtostr(double d,char *buf,unsigned int maxlen,unsigned int prec,unsigned i
   if (d==0.0) {
     prec2=prec2==0?1:prec2+2;
     prec2=prec2>maxlen?8:prec2;
-    for (i=0; i<prec2; ++i) buf[i]='0';
-    buf[1]='.'; buf[i]=0;
+    i=0;
+    if (prec2 && (long long)u.l<0) { buf[0]='-'; ++i; }
+    for (; i<prec2; ++i) buf[i]='0';
+    buf[buf[0]=='0'?1:2]='.'; buf[i]=0;
     return i;
   }
 
