@@ -17,7 +17,7 @@ static void getopterror(int which) {
 
 int getopt_long_only(int argc, char * const argv[], const char *optstring,
 		const struct option *longopts, int *longindex) {
-  static int lastidx=0,lastofs=0;
+  static int lastidx,lastofs;
   char *tmp,*arg;
   if (optind==0) optind=1;	/* whoever started setting optind to 0 should be shot */
 again:
