@@ -3,18 +3,18 @@
 #include <endian.h>
 
 int fputc_unlocked(int c, FILE *stream) {
-  if (__fflush4(stream,0)) {
+  if (!(stream->flags&CANWRITE) || __fflush4(stream,0)) {
 kaputt:
     stream->flags|=ERRORINDICATOR;
     return EOF;
   }
   if (stream->bm>=stream->buflen-1)
-    if (fflush(stream)) goto kaputt;
+    if (fflush_unlocked(stream)) goto kaputt;
   if (stream->flags&NOBUF) {
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-    if (write(stream->fd,&c,1) != 1)
+    if (__libc_write(stream->fd,&c,1) != 1)
 #else
-    if (write(stream->fd,(char*)&c+sizeof(c)-1,1) != 1)
+    if (__libc_write(stream->fd,(char*)&c+sizeof(c)-1,1) != 1)
 #endif
       goto kaputt;
     return 0;
@@ -23,7 +23,7 @@ kaputt:
   ++stream->bm;
   if (((stream->flags&BUFLINEWISE) && c=='\n') ||
       ((stream->flags&NOBUF))) /* puke */
-    if (fflush(stream)) goto kaputt;
+    if (fflush_unlocked(stream)) goto kaputt;
   return 0;
 }
 
