@@ -1,5 +1,5 @@
 #include <time.h>
 
 char *ctime(const time_t *timep) {
-  return asctime(gmtime(timep));
+  return asctime(localtime(timep));
 }
