@@ -4,7 +4,7 @@
 
 #ifdef WANT_TZFILE_PARSER
 extern void __maplocaltime(void);
-extern time_t __tzfile_map(time_t t, int *isdst);
+extern time_t __tzfile_map(time_t t, int *isdst, int forward);
 #else
 extern long int timezone;
 extern int daylight;
@@ -14,7 +14,7 @@ struct tm* localtime_r(const time_t* t, struct tm* r) {
   time_t tmp;
 #ifdef WANT_TZFILE_PARSER
   __maplocaltime();
-  tmp=__tzfile_map(*t,&r->tm_isdst);
+  tmp=__tzfile_map(*t,&r->tm_isdst,1);
 #else
   struct timezone tz;
   gettimeofday(0, &tz);
