@@ -3,9 +3,8 @@
 #include <signal.h>
 
 const char* strsignal(int sig) {
-  if (sig<=SIGUNUSED) return sys_siglist[sig];
-  else if ((sig>=SIGRTMIN)&&(sig<=SIGRTMAX))
-    return "Real time signal";
+  if (sig<=SIGRTMAX)
+    return sys_siglist[sig];
   else
     return "(unknown signal)";
 }
