@@ -1,4 +1,8 @@
 
+
+
+
+
 #define __NR_exit		  1
 #define __NR_fork		  2
 #define __NR_read		  3
@@ -15,8 +19,6 @@
 #define __NR_mknod		 14
 #define __NR_chmod		 15
 #define __NR_lchown		 16
-//#define __NR_break		 17
-//#define __NR_oldstat		 18
 #define __NR_lseek		 19
 #define __NR_getpid		 20
 #define __NR_mount		 21
@@ -26,14 +28,10 @@
 #define __NR_stime		 25
 #define __NR_ptrace		 26
 #define __NR_alarm		 27
-//#define __NR_oldfstat		 28
 #define __NR_pause		 29
 #define __NR_utime		 30
-//#define __NR_stty		 31
-//#define __NR_gtty		 32
 #define __NR_access		 33
 #define __NR_nice		 34
-//#define __NR_ftime		 35
 #define __NR_sync		 36
 #define __NR_kill		 37
 #define __NR_rename		 38
@@ -42,7 +40,6 @@
 #define __NR_dup		 41
 #define __NR_pipe		 42
 #define __NR_times		 43
-//#define __NR_prof		 44
 #define __NR_brk		 45
 #define __NR_setgid		 46
 #define __NR_getgid		 47
@@ -51,13 +48,9 @@
 #define __NR_getegid		 50
 #define __NR_acct		 51
 #define __NR_umount2		 52
-//#define __NR_lock		 53
 #define __NR_ioctl		 54
 #define __NR_fcntl		 55
-//#define __NR_mpx		 56
 #define __NR_setpgid		 57
-//#define __NR_ulimit		 58
-//#define __NR_oldolduname	 59
 #define __NR_umask		 60
 #define __NR_chroot		 61
 #define __NR_ustat		 62
@@ -66,23 +59,19 @@
 #define __NR_getpgrp		 65
 #define __NR_setsid		 66
 #define __NR_sigaction		 67
-//#define __NR_sgetmask		 68
-//#define __NR_ssetmask		 69
 #define __NR_setreuid		 70
 #define __NR_setregid		 71
 #define __NR_sigsuspend		 72
 #define __NR_sigpending		 73
 #define __NR_sethostname	 74
 #define __NR_setrlimit		 75
-#define __NR_getrlimit		 76	/* Back compatible 2Gig limited rlimit */
+#define __NR_getrlimit		 76
 #define __NR_getrusage		 77
 #define __NR_gettimeofday	 78
 #define __NR_settimeofday	 79
 #define __NR_getgroups		 80
 #define __NR_setgroups		 81
-//#define __NR_select		 82
 #define __NR_symlink		 83
-//#define __NR_oldlstat		 84
 #define __NR_readlink		 85
 #define __NR_uselib		 86
 #define __NR_swapon		 87
@@ -96,7 +85,6 @@
 #define __NR_fchown		 95
 #define __NR_getpriority	 96
 #define __NR_setpriority	 97
-//#define __NR_profil		 98
 #define __NR_statfs		 99
 #define __NR_fstatfs		100
 #define __NR_ioperm		101
@@ -107,11 +95,9 @@
 #define __NR_stat		106
 #define __NR_lstat		107
 #define __NR_fstat		108
-//#define __NR_olduname		109
-//#define __NR_iopl		110
+#define __NR_lookup_dcookie     110
 #define __NR_vhangup		111
 #define __NR_idle		112
-//#define __NR_vm86old		113
 #define __NR_wait4		114
 #define __NR_swapoff		115
 #define __NR_sysinfo		116
@@ -121,7 +107,6 @@
 #define __NR_clone		120
 #define __NR_setdomainname	121
 #define __NR_uname		122
-//#define __NR_modify_ldt		123
 #define __NR_adjtimex		124
 #define __NR_mprotect		125
 #define __NR_sigprocmask	126
@@ -164,7 +149,6 @@
 #define __NR_mremap		163
 #define __NR_setresuid		164
 #define __NR_getresuid		165
-//#define __NR_vm86		166
 #define __NR_query_module	167
 #define __NR_poll		168
 #define __NR_nfsservctl		169
@@ -186,8 +170,8 @@
 #define __NR_capset		185
 #define __NR_sigaltstack	186
 #define __NR_sendfile		187
-#define __NR_getpmsg		188	/* some people actually want streams */
-#define __NR_putpmsg		189	/* some people actually want streams */
+#define __NR_getpmsg		188
+#define __NR_putpmsg		189
 #define __NR_vfork		190
 #define __NR_ugetrlimit		191	/* SuS compliant getrlimit */
 #define __NR_mmap2		192
@@ -218,7 +202,6 @@
 #define __NR_pivot_root		217
 #define __NR_mincore		218
 #define __NR_madvise		219
-#define __NR_madvise1		219	/* delete when C lib stub is removed */
 #define __NR_getdents64		220
 #define __NR_fcntl64		221
 #define __NR_readahead		222
@@ -240,7 +223,7 @@
 #define __NR_futex		238
 #define __NR_sched_setaffinity	239
 #define __NR_sched_getaffinity	240
-#define __NR_security		241	/* syscall for security modules */
+#define __NR_tgkill		241
 /*
  * Number 242 is reserved for tux
  */
@@ -254,6 +237,31 @@
 #define __NR_epoll_ctl		250
 #define __NR_epoll_wait		251
 #define __NR_set_tid_address	252
+#define __NR_fadvise64		253
+#define __NR_timer_create	254
+#define __NR_timer_settime	(__NR_timer_create+1)
+#define __NR_timer_gettime	(__NR_timer_create+2)
+#define __NR_timer_getoverrun	(__NR_timer_create+3)
+#define __NR_timer_delete	(__NR_timer_create+4)
+#define __NR_clock_settime	(__NR_timer_create+5)
+#define __NR_clock_gettime	(__NR_timer_create+6)
+#define __NR_clock_getres	(__NR_timer_create+7)
+#define __NR_clock_nanosleep	(__NR_timer_create+8)
+/* Number 263 is reserved for vserver */
+#define __NR_fadvise64_64	264
+#define __NR_statfs64		265
+#define __NR_fstatfs64		266
+/* Number 267 is reserved for new sys_remap_file_pages */
+/* Number 268 is reserved for new sys_mbind */
+/* Number 269 is reserved for new sys_get_mempolicy */
+/* Number 270 is reserved for new sys_set_mempolicy */
+#define __NR_mq_open		271
+#define __NR_mq_unlink		272
+#define __NR_mq_timedsend	273
+#define __NR_mq_timedreceive	274
+#define __NR_mq_notify		275
+#define __NR_mq_getsetattr	276
+/* Number 277 is reserved for new sys_kexec_load */
 
 #define syscall_weak(name,wsym,sym) \
 .text; \
@@ -263,7 +271,12 @@ wsym: ; \
 .type sym,@function; \
 .global sym; \
 sym: \
+	.if __NR_##name < 256 ; \
 	svc __NR_##name ; \
+	.else ; \
+	la %r1,__NR_##name ; \
+	svc 0 ; \
+	.endif ; \
 	j __unified_syscall
 
 #define syscall(name,sym) \
@@ -271,6 +284,11 @@ sym: \
 .type sym,@function; \
 .global sym; \
 sym: \
+	.if __NR_##name < 256 ; \
 	svc __NR_##name ; \
+	.else ; \
+	la %r1,__NR_##name ; \
+	svc 0 ; \
+	.endif ; \
 	j __unified_syscall
 
