@@ -1,6 +1,10 @@
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
+#include <arpa/inet.h>
 #include <netdb.h>
 
 int main() {
@@ -30,4 +34,5 @@ int main() {
     }
     ai=ai->ai_next;
   }
+  return 0;
 }
